# ChattyCathy
Artificial intelligence (AI) chat bot for Discord written in Python

# Project Home Page

Visit the project page on DevDungeon.com for more information.

https://www.devdungeon.com/content/chatty-cathy

# AIML Tutorial

For more details on using AIML with Python, see the tutorial on DevDungeon.

https://www.devdungeon.com/content/ai-chat-bot-python-aiml

# Live Demo

Chat with Chatty Cathy in the DevDungeon Discord server channel #chat-with-cathy.

https://discord.gg/unSddKm

# Set up your own bot

Run your own bot by following the instructions below.

## Installation

    pip install cathy
    
Or download this package and install with setup.py 

    python setup.py install
    
## Running

    cathy --help
    
## Usage

    Cathy.

    Discord chat bot using AIML artificial intelligence

    Usage:
      cathy <channel> <token>
    
    Options:
      <channel>     Name of channel to chat in (no hashtag)
      <token>       Bot's Discord API token
      -h --help     Show this screen.
      
## Example Usage

    cathy chat-with-cathy XXXXXXSECRETTOKENXXXXXXX

## Contact

nanodano@devdungeon.com
